package VMOMI::ClusterInfraUpdateHaConfigInfoRemediationType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
